@@ -4,7 +4,7 @@
 #
 
 package Parallel::WorkUnit;
-$Parallel::WorkUnit::VERSION = '1.014'; # TRIAL
+$Parallel::WorkUnit::VERSION = '1.015'; # TRIAL
 use v5.8;
 
 # ABSTRACT: Provide easy-to-use forking with ability to pass back data
@@ -14,17 +14,23 @@ use warnings;
 use autodie;
 
 use Try::Tiny;
-my $do_thread;
-## no critic (BuiltinFunctions::ProhibitStringyEval)
-$do_thread = eval 'use threads qw//; 1' if $^O eq 'MSWin32';
-## critic
-if ($do_thread) { eval 'use Thread::Queue;'; }
+
+#
+# Setting up threads, on Win32, if appropriate
+#
 
 my $use_anyevent_pipe;
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 $use_anyevent_pipe = eval 'use AnyEvent::Util qw//; 1' if $^O eq 'MSWin32';
 ## critic
-if ($use_anyevent_pipe) { eval 'use AnyEvent::Util;'; }
+
+my $use_threads;
+## no critic (BuiltinFunctions::ProhibitStringyEval)
+$use_threads = eval 'use threads qw//; 1' if ( ( $^O eq 'MSWin32' ) && ( !$use_anyevent_pipe ) );
+## critic
+if ($use_threads) { eval 'use Thread::Queue;'; }
+
+my $use_thread_queue = ( $use_threads && ( !$use_anyevent_pipe ) );
 
 use Carp;
 
@@ -102,7 +108,7 @@ sub BUILD {
 
     $self->_subprocs( {} );
 
-    if ($do_thread) {
+    if ($use_thread_queue) {
         $self->_queue( Thread::Queue->new() );
     }
 
@@ -126,7 +132,7 @@ sub async {
     }
 
     my ( $pid, $thr );
-    if ($do_thread) {
+    if ($use_threads) {
         $pid = $self->_count();
         $self->_count( $pid + 1 );
 
@@ -185,7 +191,7 @@ sub _child {
     };
 
     # Windows doesn't do fork(), it does threads...
-    if ($do_thread) {
+    if ($use_threads) {
         return 1;
     } else {
         exit();
@@ -251,7 +257,7 @@ sub _waitone {
     my $sp = $self->_subprocs();
     if ( !keys(%$sp) ) { return; }
 
-    if ($do_thread) {
+    if ($use_thread_queue) {
         # On Windows
         #
         my $child = $self->_queue()->dequeue();
@@ -279,7 +285,7 @@ sub _waitone {
                         my $thr = $self->_subprocs()->{$child}{thread};
                         $self->_read_result($child);
 
-                        if ($do_thread) {
+                        if ($use_threads) {
                             $thr->join();
                         } else {
                             waitpid( $child, 0 );
@@ -332,7 +338,7 @@ sub _wait {
     my $thr    = $self->_subprocs()->{$pid}{thread};
     my $result = $self->_read_result($pid);
 
-    if ($do_thread) {
+    if ($use_threads) {
         $thr->join();
     } else {
         waitpid( $pid, 0 );
@@ -387,7 +393,7 @@ sub _send {
         die 'freeze() returned undef for child return value';
     }
 
-    if ($do_thread) {
+    if ($use_thread_queue) {
         $self->_queue()->enqueue($pid);
     }
 
@@ -442,7 +448,7 @@ sub _read_result {
     if ( $type eq 'RESULT' ) {
         $cinfo->{callback}->($data);
     } else {
-        if ($do_thread) { $thr->join(); }
+        if ($use_threads) { $thr->join(); }
 
         my $err =
             "Child (created at "
@@ -566,7 +572,7 @@ Parallel::WorkUnit - Provide easy-to-use forking with ability to pass back data
 
 =head1 VERSION
 
-version 1.014
+version 1.015
 
 =head1 SYNOPSIS
 
@@ -678,10 +684,10 @@ can spawn a new child regardless of the number of children already
 spawned. However, you children started with this method still count
 against the limit used by C<queue()>.
 
-Note: on Windows with threaded Perl, threads instead of forks are used.
-See C<thread> for the caveats that apply.  The PID returned is instead
-a meaningless (outside of this module) counter, not associated with any
-Windows thread identifier.
+Note: on Windows with threaded Perl, if C<AnyEvent> is not installed,
+threads instead of forks are used.  See C<thread> for the caveats
+that apply.  The PID returned is instead a meaningless (outside of
+this module) counter, not associated with any Windows thread identifier.
 
 =head2 waitall()
 
@@ -732,16 +738,6 @@ C<max_children>) and not returning a PID.  Instead, a value of 1
 is returned if the process is immediately started, C<undef>
 otherwise.
 
-=head1 BUGS
-
-Windows doesn't do C<fork()>, but emulates it with threads.  As a result,
-any thread unsafe library is going to cause problems with Windows.  In
-addition, all the normal thread caveats apply - see L<threads> for more
-information.
-
-In addition, this code is unlikely to function properly on a Windows without
-threaded Perl.
-
 =head1 AUTHOR
 
 Joelle Maslak <jmaslak@antelope.net>
